/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#include <stdio.h>
#include <pthread.h>
#include <unistd.h>

#include "Semaphore.h"

static struct Semaphore_Data Exec_Semaphore;
static struct Semaphore_Data Hostlist_Semaphore;
static struct Semaphore_Data Hostcount_Semaphore;
static int MaxHostCount;

void Init_Semaphores(int LMaxHostCount) {
	Semaphore_Init(&Exec_Semaphore, 1);
	Semaphore_Init(&Hostlist_Semaphore, 1);
	Semaphore_Init(&Hostcount_Semaphore, LMaxHostCount);
	MaxHostCount = LMaxHostCount;
}

void Lock_Exec() {
	P(&Exec_Semaphore);
}

void Unlock_Exec() {
	V(&Exec_Semaphore);
}

void Lock_Stringlist() {
	P(&Hostlist_Semaphore);
}

void Unlock_Stringlist() {
	V(&Hostlist_Semaphore);
}

void HostCnt_Inc() {
	P(&Hostcount_Semaphore);
}

void HostCnt_Dec() {
	V(&Hostcount_Semaphore);
}

void Waitfor_HostCnt() {
	while (Hostcount_Semaphore.Value!=MaxHostCount) {
/*		printf("Waiting for hostcnt to increase (currently %d, waiting for %d)...\n", Hostcount_Semaphore.Value, MaxHostCount); */
		usleep(100*1000);
	}
}

